var DomainBuilder =
/*#__PURE__*/
function () {
  DomainBuilder.extend = function extend(_ref) {
    var _ref$domain = _ref.domain,
        domain = _ref$domain === void 0 ? {} : _ref$domain;
    return new DomainBuilder({
      domain: domain
    });
  };

  function DomainBuilder(_temp) {
    var _ref2 = _temp === void 0 ? {} : _temp,
        domain = _ref2.domain;

    this._domain = domain;
    this._useCase = false;
    this._config = domain.get('config');
    this._useCases = {};
  }

  var _proto = DomainBuilder.prototype;

  _proto.for = function _for(_temp2) {
    var _ref3 = _temp2 === void 0 ? {} : _temp2,
        useCase = _ref3.useCase;

    if (this._useCase) {
      throw new Error("[DomainBuilder#for] There is already an use case " + this._useCases + ".\n         Set up a response with DomainBuilder#respondWith before setting up another use case");
    }

    this._useCase = useCase;
    return this;
  };

  _proto.respondWith = function respondWith(_temp3) {
    var _ref4 = _temp3 === void 0 ? {} : _temp3,
        success = _ref4.success,
        fail = _ref4.fail;

    if (success !== undefined && fail !== undefined) {
      throw new Error('[DomainBuilder#respondWith] The response must set an object with success or fail prop, but not both');
    }

    if (success === undefined && fail === undefined) {
      throw new Error('[DomainBuilder#respondWith] Neither success nor fail are set');
    }

    if (!this._useCase) {
      throw new Error('[DomainBuilder#respondWith] before setting a response you must set up a use case using the DomainBuilder#for function');
    }

    this._useCases[this._useCase] = {
      success: success,
      fail: fail
    };
    this._useCase = false;
    return this;
  };

  _proto.build = function build() {
    var _this = this;

    var self = this;
    return {
      get: function get(useCase) {
        if (useCase === 'config') {
          return _this._config;
        }

        return self._useCases[useCase] ? {
          execute: function execute(params) {
            var successResponse = self._useCases[useCase]['success'];
            return self._useCases[useCase]['success'] !== undefined ? Promise.resolve(typeof successResponse === 'function' ? successResponse(params) : successResponse) : Promise.reject(self._useCases[useCase]['fail']);
          }
        } : self._domain.get(useCase);
      },
      _map: Object.assign(self._domain._map || {}, self._useCases),
      useCases: Object.assign(self._domain.useCases || {}, self._useCases)
    };
  };

  return DomainBuilder;
}();

export { DomainBuilder as default };